# Backtrace e-mail service

This repository contains a code responsible for the backtrace-email service -
the service responsible for sending emails to Backtrace users.

## Getting started

To run and build application follow instructions below:

```
npm run build
npm run start
```

## Translation extraction

All items that use the `i18n` lambda within mustache can be extracted using the
extraction tool provided. This will use the lambda feature of the `mustache`
templates to extract the strings to a file.

1. load mjml file listing
2. for each file:
   1. load file
   2. parse with mustache
   3. collect strings using the lambda
   4. write strings to file.

## Translation Catalog

This is built upon service start from the configured path to the compiled
[MO](MO - GetText Machine Object) files.

These files are expected to be placed into the `i18n/mo` directory with each
languaged being represented by a `backtrace_hermes.mo` file under that languages
[ISO 639-1] standard code named directory. This file structure mirrors that of
the [PO](PO - GetText Portable Object) file directory structure.

The [MO](MO) files are compiled during the build phase of the project,
therefore, all [PO](PO) files must be present at build time.

The translation catalog is a HashMap from [ISO 639-1] code to the in-memory
representation of the [MO](MO) file that is required for gettext lookup. The
system will use the user provided [ISO 639-1] language code to look up the
appropriate [MO](MO) file to pass to the gettext translation function.

## Translation runtime

How will we use the extracted strings at runtime?

1. Compile MRML to handlebars template strings.
2. Inject i18n helper loaded with the proper language..
3. compile the proper template.
4. Profit.

## Template

-- Going to require that each template have a "Front Matter" section. The "Front
Matter" section will be a tagged comment that MUST appear at the top of the
template file. The tag MUST be `[BT]`. Using a comment so that standard
[MJML](MJML) tools will continue to work on our templates. -- --Going to
re-purpose part of [Zola's Front Matter parser].-- -- Should we require that
each template have a unique name? Or, should this be based upon the filename?

### What are the things that should be required in the front matter?

-- `context` - This will be treated as a raw JSON object. This JSON will be
combined with the template context. This provides a way of statically defining
some context data. -- `schema` - A [jsonschema](JSON schema) that will be used
to validate the template context data before passing it to
[handlebars](Handlebars) -- `subject` - A Handlebars template for the email's
subject line. This will automatically be run through the i18n system, useing the
`i18n` helper is not required and will generate an error.

[handlebars]: https://crates.io/crates/handlebars
[iso 639-1]: https://www.iso.org/standard/22109.html
[jsonschema]: https://crates.io/crates/jsonschema
[mjml]: https://mjml.io
[mo]: https://www.gnu.org/software/gettext/manual/html_node/MO.html#MO
[po]: https://www.gnu.org/software/gettext/manual/html_node/PO.html#PO
[tracing]: https://crates.io/crates/tracing
[zola's front matter parser]:
  https://github.com/getzola/zola/blob/e186f0851689763d94c096a1bd6b0732953d7e02/components/front_matter/src/lib.rs

### Translation useful commands

```
cd ./i18n/po
find . -name \*.po -execdir msgfmt backtrace_hermes.po -o backtrace_hermes.mo \;
// move all .mo files generated in the `po` directory to the equivalent folders in the `mo` directory
```
