"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeAppFromService = void 0;
const rustic_1 = require("rustic");
const future_1 = require("../internal/future");
const file_system_1 = require("../internal/file-system");
const HashMap_1 = require("../internal/HashMap");
const i18n_1 = require("../i18n");
const source_file_po_1 = require("../i18n/source-file-po");
const mjml_1 = require("../mjml");
const smtp_1 = require("../smtp");
const impl_1 = require("./impl");
const override_1 = require("./override");
function makeAppFromService(svc, userOverrides) {
    const overrides = (0, rustic_1.equip)(userOverrides).unwrapOrElse(override_1.makeDefault);
    const smtp = new smtp_1.Transport(svc.getSmtpConfig());
    const transport = () => smtp;
    const i18nFuture = makeI18nSource(svc, overrides.i18n);
    const mjmlFuture = makeTemplateSource(svc, overrides.template);
    const makeApp = (i18n, template) => {
        return new impl_1.App({ i18n, template, transport });
    };
    return future_1.Future.equip(i18nFuture).map2(mjmlFuture, makeApp).inner;
}
exports.makeAppFromService = makeAppFromService;
function makeI18nSource(svc, override) {
    const fn = () => {
        const config = {
            cache: new HashMap_1.HashMap(),
            fileSystem: file_system_1.NodeFS,
            path: svc.getI18nPath(),
            renderConstructor: new i18n_1.HandlebarsConstructor(() => new HashMap_1.HashMap()),
        };
        return (0, source_file_po_1.makeI18nPoContainer)(config);
    };
    return (0, override_1.maker)(override, fn);
}
function makeTemplateSource(svc, override) {
    const fn = () => mjml_1.MjmlFileLoader.make(file_system_1.NodeFS, svc.getTemplatePath());
    return (0, override_1.maker)(override, fn);
}
//# sourceMappingURL=from-backtrace-service.js.map