"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthManagerMiddleware = void 0;
const backtrace_service_1 = require("backtrace-service");
class AuthManagerMiddleware {
    constructor(_identityManager, _ipAddressResolver, _logger) {
        this._identityManager = _identityManager;
        this._ipAddressResolver = _ipAddressResolver;
        this._logger = _logger;
        this._coronerdLocationHeaderName = 'x-coroner-location';
    }
    authenticateRequest() {
        return async (req, res, next) => {
            const requestIp = req.socket.remoteAddress;
            if (!this._ipAddressResolver.isWhiteListed(requestIp)) {
                this._identityManager.authenticateRequest()(req, res, next);
                return;
            }
            const coronerdAddress = this.getCoronerdLocationHeader(req);
            if (coronerdAddress) {
                const configuration = await this._identityManager.loginCoronerd(coronerdAddress);
                if (configuration) {
                    req.coronerAuth = {
                        cfg: configuration,
                        token: undefined,
                        url: coronerdAddress,
                    };
                    next();
                    return;
                }
            }
            this._logger.warn(`Detected unauthorized access via localhost flow. Coronerd address : ${coronerdAddress} req ip: ${requestIp}`);
            this._identityManager.bypassProjectAccessCheck(res);
            next(new backtrace_service_1.ApiError('Access denied', 403));
        };
    }
    getCoronerdLocationHeader(req) {
        return req.headers[this._coronerdLocationHeaderName];
    }
}
exports.AuthManagerMiddleware = AuthManagerMiddleware;
//# sourceMappingURL=authManagerMiddleware.js.map