"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegrationRoutes = void 0;
const express_1 = require("express");
const rustic_1 = require("rustic");
const i18n_1 = require("../i18n");
const authManagerMiddleware_1 = require("./authManagerMiddleware");
const ipResolver_1 = require("./ipResolver");
class IntegrationRoutes {
    constructor(_logger, _sender, _translation, _identityManager, whitelistedIpAddresses, _authManagerMiddleware = new authManagerMiddleware_1.AuthManagerMiddleware(_identityManager, new ipResolver_1.IpAddressResolver(whitelistedIpAddresses), _logger)) {
        this._logger = _logger;
        this._sender = _sender;
        this._translation = _translation;
        this._identityManager = _identityManager;
        this.whitelistedIpAddresses = whitelistedIpAddresses;
        this._authManagerMiddleware = _authManagerMiddleware;
        this._templateName = '/:templateName';
    }
    configure() {
        const router = (0, express_1.Router)();
        router.post(this._templateName, this._authManagerMiddleware.authenticateRequest(), async (req, res) => {
            this._identityManager.bypassProjectAccessCheck(res);
            const { templateName } = req.params;
            if (!templateName) {
                res.status(400).send({
                    message: 'Invalid template name',
                });
                return;
            }
            const data = req.body;
            if (!data.to) {
                res.status(400).send({
                    message: 'Missing e-mail recipient - missing "to" parameter'
                });
                return;
            }
            this._logger.info(`Creating an e-mail for data = (template: ${templateName}, to: ${data.to}, subject: ${data.subject})`);
            this._logger.debug(`Request payload: ${JSON.stringify(data)}`);
            const result = await this._translation.send({
                lang: data.lang || i18n_1.Iso3166.English,
                recipient: data.to,
                template: templateName,
                sender: this._sender,
                context: data,
            });
            if ((0, rustic_1.isErr)(result)) {
                this._logger.error(`Received an unhandled exception. Reason: ${result.data}`);
                res.status(500).send({
                    message: 'Internal server error with email translation or send failure.',
                });
                return;
            }
            res.status(200).send({
                message: 'e-mail scheduled to send',
            });
            return;
        });
        return router;
    }
}
exports.IntegrationRoutes = IntegrationRoutes;
//# sourceMappingURL=integrationRoutes.js.map