"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateRoutes = void 0;
const express_1 = require("express");
const rustic_1 = require("rustic");
const i18n_1 = require("../i18n");
class TemplateRoutes {
    constructor(_logger, _translation, _identityManager) {
        this._logger = _logger;
        this._translation = _translation;
        this._identityManager = _identityManager;
        this._templateName = '/:templateName';
    }
    configure() {
        const router = (0, express_1.Router)();
        router.get(this._templateName, this._identityManager.authenticateRequest(), async (req, res) => {
            this._identityManager.bypassProjectAccessCheck(res);
            const { templateName } = req.params;
            if (!templateName) {
                res.status(400).send({
                    message: 'Invalid template name',
                });
                return;
            }
            const lang = req.query.lang || i18n_1.Iso3166.English;
            this._logger.info(`Generating an e-mail template for data = (template: ${templateName}, lang: ${lang})`);
            const result = await this._translation.render({
                context: req.query,
                lang,
                template: templateName,
            });
            if ((0, rustic_1.isErr)(result)) {
                const message = `Received an exception on the email template generation stage. Reason: ${result.data}`;
                this._logger.error(message);
                res.status(422).send({
                    message,
                });
                return;
            }
            res.status(200).send(result.data.content);
            return;
        });
        return router;
    }
}
exports.TemplateRoutes = TemplateRoutes;
//# sourceMappingURL=templateRoutes.js.map