"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryIntoResult = exports.FailUnknown = exports.FailParse = void 0;
const rustic_1 = require("rustic");
class FailAbstract extends Error {
    constructor(message) {
        super(message);
    }
    getMessage() {
        return this.message;
    }
}
class FailParse extends FailAbstract {
    constructor(message) {
        super(message);
        this.code = "ERROR_PARSE";
    }
}
exports.FailParse = FailParse;
class FailUnknown extends FailAbstract {
    constructor(message) {
        super(message);
        this.code = "ERROR_UNKNOWN";
    }
}
exports.FailUnknown = FailUnknown;
function tryIntoResult(fn, errorHandler) {
    try {
        return (0, rustic_1.Ok)(fn());
    }
    catch (error) {
        const customError = errorHandler(error);
        if (customError !== null) {
            return (0, rustic_1.Err)(customError);
        }
        if (typeof error !== 'object') {
            return (0, rustic_1.Err)(new FailUnknown(String(error)));
        }
        if (error instanceof Error) {
            return (0, rustic_1.Err)(new FailUnknown(error.message));
        }
        throw new TypeError(`PANIC: Don't throw garbage: \n ${String(error)}`);
    }
}
exports.tryIntoResult = tryIntoResult;
//# sourceMappingURL=fail.js.map