"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractAndParse = exports.parse = exports.extract = void 0;
const ajv_1 = __importDefault(require("ajv"));
const rustic_1 = require("rustic");
const COMMENT_TAG = '<!--[BT]';
const ajv = new ajv_1.default();
const frontMatterSchema = ajv.compile({
    type: 'object',
    properties: {
        context: { type: 'object' },
        name: { type: 'string' },
        schema: { type: 'object' },
        subject: { type: 'string' },
    },
    required: ['name', 'schema', 'subject'],
    additionalProperties: false,
});
function frontMatterParser(input) {
    if (frontMatterSchema(input)) {
        return (0, rustic_1.Ok)(input);
    }
    else {
        const errors = frontMatterSchema.errors;
        return (0, rustic_1.Err)(JSON.stringify(errors));
    }
}
function extract(input) {
    let indexStart = input.indexOf(COMMENT_TAG);
    if (indexStart == -1) {
        return (0, rustic_1.Err)('Not Found: Front Matter comment');
    }
    indexStart = indexStart + COMMENT_TAG.length;
    const indexEnd = input.indexOf('-->', indexStart);
    if (indexEnd - indexStart <= 0) {
        return (0, rustic_1.Err)('Invalid: Front Matter comment - empty');
    }
    const content = input.substring(indexStart, indexEnd).trim();
    return (0, rustic_1.Ok)(content);
}
exports.extract = extract;
function parse(input) {
    const json = (0, rustic_1.catchResult)(() => JSON.parse(input));
    return (0, rustic_1.equip)(json)
        .andThen((json) => frontMatterParser(json))
        .map((x) => x).inner;
}
exports.parse = parse;
function extractAndParse(input) {
    return (0, rustic_1.equip)(extract(input)).andThen((raw) => parse(raw)).inner;
}
exports.extractAndParse = extractAndParse;
//# sourceMappingURL=front-matter.js.map